@@ -438,6 +438,12 @@ sub profile_check_in
 		} @{$p-> {colormap}} ];
 		delete $p-> {colormap};
 	}
+
+	if ( exists $p->{size} ) {
+		$p->{width}  //= $p->{size}->[0];
+		$p->{height} //= $p->{size}->[1];
+	}
+
 	$self-> SUPER::profile_check_in( $p, $default);
 }
 
@@ -474,6 +480,22 @@ sub clone
 	return $i;
 }
 
+sub ui_scale
+{
+	my ($self, %opt) = @_;
+
+	my $zoom = delete($opt{zoom}) // ( $::application ? $::application->uiScaling : 1 );
+	return $self if $zoom == 1.0;
+
+	my $scaling = delete($opt{scaling}) // ist::Quadratic;
+	$self->set(
+		%opt,
+		scaling => $scaling,
+		size => [ map { $_ * $zoom } $self->size ],
+	);
+	return $self;
+}
+
 # class Icon
 package Prima::Icon;
 use vars qw( @ISA);
@@ -530,6 +552,31 @@ sub create_combined
 
 sub has_alpha_layer { shift->maskType == im::bpp8 }
 
+sub ui_scale
+{
+	my ($self, %opt) = @_;
+	
+	my $zoom = delete($opt{zoom}) // ( $::application ? $::application->uiScaling : 1 );
+	return $self if $zoom == 1.0;
+
+	my $argb    = delete($opt{argb})    // ($::application ? $::application-> get_system_value( sv::LayeredWidgets ) : 0);
+	my $scaling = delete($opt{scaling}) // ($argb ? ist::Quadratic : ist::Box );
+
+	if ( $scaling <= ist::Box ) {
+		# don't uglify bitmaps with box scaling where zoom is 1.25 or 2.75
+		$zoom = int($zoom + .5);
+		return if $zoom <= 1.0;
+	}
+
+	$self->set(
+		%opt,
+		scaling => $scaling,
+		size => [ map { $_ * $zoom } $self->size ],
+	);
+
+	return $self;
+}
+
 # class DeviceBitmap
 package Prima::DeviceBitmap;
 use vars qw( @ISA);
@@ -555,6 +602,10 @@ sub profile_check_in
 	if ( exists $p-> {monochrome} and not exists $p-> {type}) {
 		$p-> {type} = $p->{monochrome} ? dbt::Bitmap : dbt::Pixmap;
 	}
+	if ( exists $p->{size} ) {
+		$p->{width}  //= $p->{size}->[0];
+		$p->{height} //= $p->{size}->[1];
+	}
 	$self-> SUPER::profile_check_in( $p, $default);
 }
 
@@ -1476,6 +1527,7 @@ sub profile_default
 		printerModule  => $unix ? 'Prima::PS::Printer' : '',
 		helpClass      => 'Prima::HelpViewer',
 		helpModule     => 'Prima::HelpViewer',
+		uiScaling      => 0,
 		wantUnicodeInput => 0,
 	);
 	@$def{keys %prf} = values %prf;
@@ -1628,8 +1680,6 @@ sub on_pasteimage
 
 1;
 
-__DATA__
-
 =pod
 
 =head1 NAME
