@@ -38,6 +38,8 @@ package
 sub blend($)
 {
    my $alpha = 255 - shift;
+   $alpha = 0 if $alpha < 0;
+   $alpha = 255 if $alpha > 255;
    return rop::DstAtop | rop::ConstantAlpha | ( $alpha << rop::SrcAlphaShift ) | ($alpha << rop::DstAlphaShift);
 }
 
@@ -106,8 +108,6 @@ package
 
 1;
 
-__DATA__
-
 =pod
 
 =head1 NAME
@@ -830,7 +830,7 @@ See also L<Prima::StdBitmap>.
 	sbmp::Warning
 	sbmp::Information
 	sbmp::Question
-	sbmp::OutlineCollaps
+	sbmp::OutlineCollapse
 	sbmp::OutlineExpand
 	sbmp::Error
 	sbmp::SysMenu
