@@ -1,5 +1,6 @@
 # Initializes Prima in no-X11 environment
 
+package Prima::noX11; # for metacpan
 package Prima;
 use Prima::Config;
 
@@ -15,8 +16,6 @@ sub XOpenDisplay
 
 1;
 
-__DATA__
-
 =head1 NAME
 
 Prima::noX11 - Use Prima without X11
