@@ -1,31 +1,3 @@
-#
-#  Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
-#  All rights reserved.
-#
-#  Redistribution and use in source and binary forms, with or without
-#  modification, are permitted provided that the following conditions
-#  are met:
-#  1. Redistributions of source code must retain the above copyright
-#     notice, this list of conditions and the following disclaimer.
-#  2. Redistributions in binary form must reproduce the above copyright
-#     notice, this list of conditions and the following disclaimer in the
-#     documentation and/or other materials provided with the distribution.
-#
-#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-#  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-#  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-#  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-#  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-#  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-#  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-#  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-#  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#  SUCH DAMAGE.
-#
-#  $Id$
-#
-
 =pod
 
 =head1 NAME
@@ -44,7 +16,7 @@ use warnings;
 
 use Prima;
 use Prima::Edit;
-use Prima::Bidi qw(:enable);
+use Prima::Bidi;
 use Prima::Application;
 use Prima::MsgBox;
 use Prima::StdDlg;
@@ -67,7 +39,7 @@ sub profile_default
 		growMode => gm::Floor,
 		left     => 0,
 		bottom   => 0,
-		height   => 21,
+		height   => $::application->font->height + 2,
 	}
 }
 
@@ -223,11 +195,12 @@ sub init
 		}
 	}
 	$fn = '.Untitled' unless defined $fn;
+	my $fh = $::application->font->height + 1;
 	$self-> {editor} = $self-> insert( Editor =>
 		name      => 'Edit',
 		textRef   => \$cap,
-		origin    => [ 0, 22],
-		size      => [ $self-> width, $self-> height - 22],
+		origin    => [ 0, $fh],
+		size      => [ $self-> width, $self-> height - $fh],
 		hScroll   => 1,
 		vScroll   => 1,
 		growMode  => gm::Client,
