@@ -5,20 +5,26 @@
 # XXX backport tb's to TextView
 use strict;
 use warnings;
-use Prima qw(Application MsgBox Buttons Edit Notebooks Label DetailedList Outlines Drawable::Markup);
+use Prima qw(Application Buttons Edit Notebooks Label DetailedList Outlines Drawable::Markup);
+use Prima::MsgBox;
+use FindBin qw($Bin);
 
 my $fp = [
 	{ name   => 'Times New Roman' },
 	{ name   => 'Courier New'     },
 	{ direction => 4 },
 ];
+my $img = [
+    Prima::Icon->load("$Bin/Hand.gif")
+];
 
-sub M($) { Prima::Drawable::Markup->new(markup => $_[0], fontPalette => $fp ) }
+sub M($) { Prima::Drawable::Markup->new(markup => $_[0], fontPalette => $fp, picturePalette => $img ) }
 
 my $Main = Prima::MainWindow->create(
 	name   => 'Main',
 	text   => 'Markup test',
 	size   => [500,500],
+	designScale => [7, 16],
 );
 
 my $tn = $Main->insert('TabbedNotebook',
@@ -45,13 +51,13 @@ $tn->insert_to_page(0,'Button',
 );
 
 $tn->insert_to_page(0,'Radio',
-	text   => M 'Some S<+2|U<b>ig text> in a radio button',
+	text   => M 'P<0>Some S<+2|U<b>ig text> in a radio button',
 	pack   => { side => 'top' , anchor => 'w'},
 	hotKey => 'b',
 );
 
 $tn->insert_to_page(0,'CheckBox',
-	text   => M 'Some S<-2|U<s>mall text> in a checkbox',
+	text   => M 'P<0>Some S<-2|U<s>mall text> in a checkbox',
 	pack   => { side => 'top' , anchor => 'w'},
 	hotKey => 's',
 );
