@@ -623,8 +623,8 @@ typedef struct _UnixGuts
 	int                          visualClass;
 	XVisualInfo                  argb_visual;
 #ifdef HAVE_X11_EXTENSIONS_XRENDER_H
-	XRenderPictFormat *          argb_pic_format;
-	XRenderPictFormat *          argb_compat_format;
+	XRenderPictFormat *          xrender_argb_pic_format;
+	XRenderPictFormat *          xrender_argb_compat_format;
 #endif
 	MainColorEntry *             palette;
 	int                          mappingPlace[256];
@@ -701,7 +701,6 @@ typedef struct _drawable_sys_data
 	XDrawable udrawable;
 	XDrawable gdrawable;
 	XWindow parent;
-	Point resolution;
 	Point origin, size, bsize;
 	Point transform, gtransform, btransform;
 	Point ackOrigin, ackSize, ackFrameSize;   
