@@ -61,6 +61,9 @@ typedef HANDLE SOCKETHANDLE;
 #define WM_FIRST_USER_MESSAGE             ( WM_USER +100)
 #define WM_LAST_USER_MESSAGE              ( WM_USER +900)
 
+#ifndef WM_DPICHANGED
+#define WM_DPICHANGED                     0x02E0
+#endif
 
 #define WC_CUSTOM       0
 #define WC_DLG          1
@@ -596,6 +599,8 @@ extern void         wchar2char( char * dest, WCHAR * src, int lim);
 extern void         char2wchar( WCHAR * dest, char * src, int lim);
 extern void         textmetric_c2w( LPTEXTMETRICA from, LPTEXTMETRICW to);
 extern int          apcUpdateWindow( HWND wnd );
+extern void         reset_system_fonts(void);
+extern void         dpi_change(void);
 
 /* compatibility to MSVC 6 */
 #ifndef GWLP_USERDATA
