@@ -293,8 +293,10 @@ Application_fonts( Handle self, char * name, char * encoding)
 {
 	int count, i;
 	AV * glo = newAV();
-	PFont fmtx = apc_fonts( self, name[0] ? name : nil,
-		encoding[0] ? encoding : nil, &count);
+	PFont fmtx = apc_fonts( self, 
+		(name && name[0])         ? name : NULL,
+		(encoding && encoding[0]) ? encoding : NULL,
+		&count);
 	for ( i = 0; i < count; i++) {
 		SV * sv      = sv_Font2HV( &fmtx[ i]);
 		HV * profile = ( HV*) SvRV( sv);
@@ -348,11 +350,10 @@ Application_font_encodings( Handle self, char * encoding)
 	hv_iterinit(( HV*) h);
 	for (;;)
 	{
-		void *value, *key;
+		void *key;
 		STRLEN  keyLen;
 		if (( he = hv_iternext( h)) == nil)
 			break;
-		value  = HeVAL( he);
 		key    = HeKEY( he);
 		keyLen = HeKLEN( he);
 		av_push( glo, newSVpvn(( char*) key, keyLen));
@@ -977,6 +978,19 @@ Application_modalHorizon( Handle self, Bool set, Bool modalHorizon)
 	return true;
 }
 
+#define UISCALING_STEP 4
+double
+Application_uiScaling( Handle self, Bool set, double uiScaling)
+{
+	if ( !set ) return var->uiScaling;
+	if ( uiScaling < 0.00001 ) {
+		Point res = my-> get_resolution(self);
+		uiScaling  = (double)((int)((double) res.x/ (96.0/UISCALING_STEP) + 0.5)) / UISCALING_STEP; /* 96-143 = 1.5, 144-191 = 1.5 etc */
+		if ( uiScaling < 0.25 ) uiScaling = 0.25;
+	}
+	return var-> uiScaling = uiScaling;
+}
+
 Bool
 Application_wantUnicodeInput( Handle self, Bool set, Bool want_ui)
 {
