@@ -831,7 +831,7 @@ Component_notify( Handle self, char * format, ...)
 	SAVETMPS;
 	ret = call_perl_indirect( self, "notify", format, true, false, args);
 	va_end( args);
-	r = ( ret && SvIOK( ret)) ? SvIV( ret) : 0;
+	r = ( ret && SvIOK( ret)) ? (SvIV( ret) != 0) : 0;
 	if ( ret) my-> set_eventFlag( self, r);
 	FREETMPS;
 	LEAVE;
@@ -849,7 +849,7 @@ Component_notify_REDEFINED( Handle self, char * format, ...)
 	SAVETMPS;
 	ret = call_perl_indirect( self, "notify", format, true, false, args);
 	va_end( args);
-	r = ( ret && SvIOK( ret)) ? SvIV( ret) : 0;
+	r = ( ret && SvIOK( ret)) ? (SvIV( ret) != 0) : 0;
 	if ( ret) my-> set_eventFlag( self, r);
 	FREETMPS;
 	LEAVE;
@@ -981,7 +981,7 @@ Component_unlink_notifier( Handle self, Handle referer)
 		int j;
 	AGAIN:
 		for ( j = 0; j < list-> count; j += 2) {
-			if ((( long) list-> items[ j]) != referer) continue;
+			if ( list-> items[ j] != referer) continue;
 			sv_free(( SV *) list-> items[ j + 1]);
 			list_delete_at( list, j + 1);
 			list_delete_at( list, j);
