@@ -262,11 +262,18 @@ Icon_mask( Handle self, Bool set, SV * svmask)
 	void * mask;
 	int am = var-> autoMasking;
 	if ( var-> stage > csFrozen) return nilSV;
-	if ( !set)
-		return newSVpvn(( char *) var-> mask, var-> maskSize);
+	if ( !set) {
+		SV * sv = newSV_type(SVt_PV);
+		SvREADONLY_on(sv);
+		SvLEN_set(sv, 0); /* So Perl won't free it. */
+		SvPV_set(sv, var-> mask);
+		SvCUR_set(sv, var-> maskSize);
+		SvPOK_only(sv);
+		return sv;
+	}
 	mask = SvPV( svmask, maskSize);
 	if ( is_opt( optInDraw) || maskSize <= 0) return nilSV;
-	memcpy( var-> mask, mask, maskSize > var-> maskSize ? var-> maskSize : maskSize);
+	memcpy( var-> mask, mask, (maskSize > (STRLEN)var-> maskSize) ? (STRLEN)var-> maskSize : maskSize);
 	var-> autoMasking = amNone;
 	my-> update_change( self);
 	var-> autoMasking = am;
@@ -308,14 +315,17 @@ Icon_convert_mask( Handle self, int type )
 		warn("Icon::convert_mask: cannot allocate %d bytes", dstLine * var-> h);
 		return NULL;
 	}
+	bzero( ret, dstLine * var-> h);
 
 	switch (type) {
 	case imbpp1:
 		/* downgrade */
 		memset( colorref,     1, 1   );
 		memset( colorref + 1, 0, 255 );
-		for ( i = 0, dst = ret; i < var->h; i++, src += srcLine, dst += dstLine)
+		for ( i = 0, dst = ret; i < var->h; i++, src += srcLine, dst += dstLine) {
+			memset( dst, 0, dstLine );
 			bc_byte_mono_cr( src, dst, var-> w, colorref);
+		}
 		break;
 	case imbpp8:
 		/* upgrade */
@@ -416,6 +426,7 @@ Icon_update_change( Handle self)
 			warn("Not enough memory: %d bytes", var-> maskSize);
 			return;
 		}
+		bzero( var-> mask, var-> maskSize );
 		produce_mask( self);
 		if ( oldtype != imbpp1 )
 			my-> set_maskType( self, oldtype);
@@ -441,6 +452,12 @@ Icon_stretch( Handle self, int width, int height)
 		return;
 	}
 	
+	if ( var-> mask && var-> maskType == imbpp1 && var-> scaling > istBox ) {
+		/* upgrade to bpp8 */
+		my-> set_maskType( self, imbpp8 );
+	}
+	
+	
 	lineSize = LINE_SIZE( abs( width), var-> maskType );
 	newMask  = allocb( lineSize * abs( height));
 	if ( newMask == nil && lineSize > 0) {
@@ -449,14 +466,12 @@ Icon_stretch( Handle self, int width, int height)
 	}
 	var-> autoMasking = amNone;
 	if ( var-> mask) {
-		Bool hScaling, vScaling;
-		if ( var-> scaling <= istBox ) {
-			 hScaling = var->scaling & istBoxX;
-			 vScaling = var->scaling & istBoxY;
-		} else {
-			 hScaling = vScaling = 1;
+		char error[256];
+		if ( !ic_stretch( var->maskType | imGrayScale, var-> mask, oldW, oldH, newMask, width, height, var->scaling, error)) {
+			free(newMask);
+			my-> make_empty( self);
+			croak("%s", error);
 		}
-		ic_stretch( var->maskType, var-> mask, oldW, oldH, newMask, width, height, hScaling, vScaling);
 	}      
 	inherited stretch( self, width, height);
 	free( var-> mask);
