@@ -192,6 +192,39 @@ snprintf( char *buf, size_t len, const char *format, ...)
 }
 #endif
 
+#ifndef HAVE_MEMMEM
+/* copied from https://github.com/trevd/android_external_bootimage_utils/blob/master/windows/memmem.c */
+void *
+memmem(const void *l, size_t l_len, const void *s, size_t s_len)
+{
+	register char *cur, *last;
+	const char *cl = (const char *)l;
+	const char *cs = (const char *)s;
+
+	/* we need something to compare */
+	if (l_len == 0 || s_len == 0)
+		return NULL;
+
+	/* "s" must be smaller or equal to "l" */
+	if (l_len < s_len)
+		return NULL;
+
+	/* special case where s_len == 1 */
+	if (s_len == 1)
+		return memchr(l, (int)*cs, l_len);
+
+	/* the last position where its possible to find "s" in "l" */
+	last = (char *)cl + l_len - s_len;
+
+	for (cur = (char *)cl; cur <= last; cur++)
+		if (cur[0] == cs[0] && memcmp(cur, cs, s_len) == 0)
+			return cur;
+
+	return NULL;
+}
+
+#endif
+
 I32
 clean_perl_call_method( char* methname, I32 flags)
 {
@@ -1441,7 +1474,7 @@ apc_get_application(void)
 }
 
 Handle
-apc_get_core_version()
+apc_get_core_version(void)
 {
 	return PRIMA_CORE_VERSION;
 }
@@ -1578,12 +1611,13 @@ list_at( PList slf, int index)
 int
 list_first_that( PList slf, void * action, void * params)
 {
-	int toRet = -1, i, cnt = slf-> count;
+	int toRet = -1, i, cnt;
 	Handle * list;
-	if ( !action || !slf || !cnt) return -1;
+	if ( !action || !slf || !slf->count) return -1;
 	if ( !( list = allocn( Handle, slf-> count)))
 		return -1;
 	memcpy( list, slf-> items, slf-> count * sizeof( Handle));
+	cnt = slf->count;
 	for ( i = 0; i < cnt; i++)
 		if ((( PListProc) action)( list[ i], params)) {
 			toRet = i;
@@ -1710,9 +1744,10 @@ exception_remember(char * text)
 	if ( !exception_blocking ) croak( "%s", text );
 
 	if ( exception_text ) {
-		if ( !( exception_text = realloc(exception_text, strlen(text) + strlen(exception_text) + 1)))
+		char * new_text = realloc(exception_text, strlen(text) + strlen(exception_text) + 1);
+		if ( !new_text )
 			croak("not enough memory");
-		strcat( exception_text, text );
+		strcat( exception_text = new_text, text );
 	} else {
 		exception_text = duplicate_string( text );
 	}
