@@ -322,7 +322,7 @@ static unsigned short const keysym_to_unicode_ff00_ff1f[] = {
 	0x0000, 0x0000, 0x0000, 0x001b, 0x0000, 0x0000, 0x0000, 0x0000  /* 0xff18-0xff1f */
 };
 
-static unsigned short const keysym_to_unicode_ff80_ffbd[] = {
+static unsigned short const keysym_to_unicode_ff80_ffbb[] = {
 	0x0020, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, /* 0xff80-0xff87 */
 	0x0000, 0x0009, 0x0000, 0x0000, 0x0000, 0x000D, 0x0000, 0x0000, /* 0xff88-0xff8f */
 	0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, /* 0xff90-0xff97 */
@@ -330,7 +330,7 @@ static unsigned short const keysym_to_unicode_ff80_ffbd[] = {
 	0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, /* 0xffa0-0xffa7 */
 	0x0000, 0x0000, 0x002a, 0x002b, 0x002c, 0x002d, 0x002e, 0x002f, /* 0xffa8-0xffaf */
 	0x0030, 0x0031, 0x0032, 0x0033, 0x0034, 0x0035, 0x0036, 0x0037, /* 0xffb0-0xffb7 */
-	0x0038, 0x0033, 0x0000, 0x003d                                  /* 0xffb8-0xffbd */
+	0x0038, 0x0033, 0x0000, 0x003d                                  /* 0xffb8-0xffbb */
 };
 
 static unsigned int
@@ -385,8 +385,8 @@ KeySymToUcs4(KeySym keysym)
 		/* added by dk */
 	else if (keysym > 0xfeff && keysym < 0xff20)
 		return keysym_to_unicode_ff00_ff1f[keysym - 0xff00];
-	else if (keysym > 0xff80 && keysym < 0xffbe)
-		return keysym_to_unicode_ff80_ffbd[keysym - 0xff80];
+	else if (keysym > 0xff80 && keysym < 0xffbc)
+		return keysym_to_unicode_ff80_ffbb[keysym - 0xff80];
 	else 
 		return 0;
 }
