@@ -429,7 +429,6 @@ prima_make_brush( DrawableSysData * XX, int colorIndex)
 Bool
 apc_gp_init( Handle self)
 {
-	X(self)-> resolution = guts. resolution;
 	if ( guts. dynamicColors && !prima_palette_alloc( self)) return false;
 	return true;
 }
@@ -456,7 +455,7 @@ static int
 arc_completion( double * angleStart, double * angleEnd, int * needFigure)
 {
 	int max;
-	double diff = ((long)( fabs( *angleEnd - *angleStart) * 1000 + 0.5)) / 1000;
+	long diff = ((long)( fabs( *angleEnd - *angleStart) * 1000 + 0.5)) / 1000;
 
 	if ( diff == 0) {
 		*needFigure = false;
@@ -1777,7 +1776,6 @@ gp_text_out_rotated( Handle self, const char * text, int x, int y, int len, Bool
 		}
 
 		if ( PDrawable( self)-> font. style & fsStruckOut) {
-			ay =  PDrawable( self)-> font.height/2 + ( XX-> flags. paint_base_line ? 0 : XX-> font-> font. descent);
 			ay = (PDrawable( self)-> font.ascent - PDrawable( self)-> font.internalLeading)/2 +
 				+ ( XX-> flags. paint_base_line ? 0 : XX-> font-> font. descent);
 			rx. l = -ovx.x * r-> cos2. l - ay * r-> sin2. l + 0.5;
@@ -1907,7 +1905,7 @@ apc_gp_get_bpp( Handle self)
 {
 	DEFXX;
 	if ( XT_IS_BITMAP(XX)) return 1;
-	if ( XF_LAYERED(XX)) return guts. argb_pic_format-> depth;
+	if ( XF_LAYERED(XX)) return guts. argb_depth;
 	return guts. depth;
 }
 
@@ -2245,15 +2243,7 @@ apc_gp_get_line_pattern( Handle self, unsigned char *dashes)
 Point
 apc_gp_get_resolution( Handle self)
 {
-	Point ret;
-	if ( self) {
-		ret.x = X(self)-> resolution.x;
-		ret.y = X(self)-> resolution.y;
-	} else {
-		ret.x = guts.resolution.x;
-		ret.y = guts.resolution.y;
-	}
-	return ret;
+	return guts. resolution;
 }
 
 int
