@@ -1155,8 +1155,8 @@ apc_sys_get_value( int v)  /* XXX one big XXX */
 	case svYSmallIcon: 
 		{
 			int ret[4], n;
-			XIconSize * sz = nil; 
-			if ( XGetIconSizes( DISP, guts.root, &sz, &n) && ( n > 0)) {
+			XIconSize * sz = NULL; 
+			if ( XGetIconSizes( DISP, guts.root, &sz, &n) && ( n > 0) && (sz != NULL)) {
 				ret[0] = sz-> max_width; 
 				ret[1] = sz-> max_height;
 				ret[2] = sz-> min_width; 
@@ -1287,6 +1287,19 @@ apc_system_action( const char *s)
 #endif
 		}
 		break;
+	case 'r':
+		if ( strncmp( s, "resolution", 10) == 0) {
+			int dx, dy;
+			int i = sscanf( s + 10, "%u %u", &dx, &dy);
+			if ( i != 2 || (dx < 1 || dy < 1)) {
+				warn("Bad resolution\n");
+				return 0;
+			}
+			guts. resolution. x = dx;
+			guts. resolution. y = dy;
+			return nil;
+		}
+		break;
 	case 's':
 		if ( strcmp( "synchronize", s) == 0) {
 			XSynchronize( DISP, true);
