@@ -1,4 +1,3 @@
-# $Id$
 use strict;
 use Config;
 
@@ -73,7 +72,7 @@ sub Link
 			return "the B<$2> entry in the I<$1> section";
 		} else {
 			$x =~ s/\///g;
-			if ( $x =~ /^Prima|VB|cfgmaint|gencls/) {
+			if ( $x =~ /^Prima|VB|prima\-cfgmaint|prima\-gencls/) {
 				return "the I<$x> section";
 			} else {
 				return "the I<$x> entry";
@@ -111,6 +110,7 @@ if ( $build) {
 		for ( <W>) {
 			if ( m/^=for\s*podview\s*<\s*img\s*src=\"?([^\"\s]+)\"?\s*(cut\s*=\s*1)?\s*>/) {
 				my ( $gif, $eps, $do_cut) = ( $1, $1, $2);
+				$eps =~ s/\.\.\///g;
 				$eps =~ s/\//_/g;
 				$eps =~ s/\.[^\.]+$/.eps/;
 				unless ( -f $eps) {
