@@ -218,7 +218,7 @@ hwnd_to_view( HWND win)
 		( ll == ( LONG_PTR) generic_frame_handler)
 		) return h;
 
-	if ( SendMessage( win, WM_HASMATE, 0, ( LPARAM) &h) == HASMATE_MAGIC)
+	if ( SendMessage( win, WM_HASMATE, 0, ( LPARAM) &h) == (LRESULT) HASMATE_MAGIC)
 		return h;
 	return nilHandle;
 }
@@ -324,11 +324,50 @@ apc_application_get_size( Handle self)
 	return ret;
 }
 
+#define PRIMA_MAX_MONITORS 1024
+typedef struct {
+	int nrects;
+	int max_height;
+	Rect2 rects[PRIMA_MAX_MONITORS];
+} EnumMonitorData;
+
+static BOOL
+_enum_monitors( HMONITOR monitor, HDC dc, LPRECT rect, LPARAM data)
+{
+	EnumMonitorData * d;
+	Rect2 * current;
+
+	d = ( EnumMonitorData * ) data;
+	if ( d-> nrects >= PRIMA_MAX_MONITORS ) return false;
+	current = &d->rects[ d->nrects ];
+
+	current-> x = rect-> left;
+	current-> y = rect-> bottom; /* fixup later */
+	current-> width = rect-> right - rect-> left;
+	current-> height = rect-> bottom - rect-> top;
+	if ( d-> max_height < rect-> bottom ) d-> max_height = rect-> bottom;
+	d->nrects++;
+
+	return true;
+}
+
 Rect2 *
 apc_application_get_monitor_rects( Handle self, int * nrects)
 {
-	*nrects = 0;
-	return nil;
+	int i;
+	Rect2 * ret;
+	EnumMonitorData d = {0,0};
+
+	EnumDisplayMonitors( NULL, NULL, (MONITORENUMPROC) _enum_monitors, (LPARAM) &d);
+	if ( d. nrects == 0) return NULL;
+	if (!(ret = malloc( d.nrects * sizeof(Rect2) )))
+		return NULL;
+
+	for ( i = 0; i < d.nrects; i++)
+		d.rects[i]. y = d.max_height - d.rects[i]. y;
+	memcpy( ret, d.rects, d.nrects * sizeof(Rect2));
+	*nrects = d.nrects;
+	return ret;
 }
 
 static void
@@ -365,9 +404,9 @@ process_msg( MSG * msg)
 		return false;
 	case WM_CROAK:
 		if ( msg-> wParam)
-			croak(( char *) msg-> lParam);
+			croak("%s", ( char *) msg-> lParam);
 		else
-			warn(( char *) msg-> lParam);
+			warn("%s", ( char *) msg-> lParam);
 		return true;
 	case WM_SYSKEYDOWN:
 		/*
@@ -3466,7 +3505,7 @@ win32_openfile( const char * params)
 		o. Flags = 0;
 		while ( *params) {
 			char * cp = ( char *) params, pp;
-			while ( *cp && *cp != ',') *cp++;
+			while ( *cp && *cp != ',') cp++;
 			pp = *cp;
 			*cp = 0;
 			if ( stricmp( params, "READONLY") == 0) o. Flags |=              OFN_READONLY; else
@@ -3566,6 +3605,21 @@ apc_system_action( const char * params)
 			return duplicate_string( buf);
 		}
 		break;
+	case 'r':
+		if ( strncmp( params, "resolution", 10) == 0) {
+			int dx, dy;
+			int i = sscanf( params + 10, "%u %u", &dx, &dy);
+			if ( i != 2 || (dx < 1 || dy < 1)) {
+				warn("Bad resolution\n");
+				return 0;
+			}
+			guts. displayResolution. x = dx;
+			guts. displayResolution. y = dy;
+			reset_system_fonts();
+			destroy_font_hash();
+			font_clean();
+		}
+		break;
 	case 'w':
 		if ( strncmp( params, "win32.DrawFocusRect ", 20) == 0) {
 			RECT r;
