@@ -1215,13 +1215,13 @@ apc_gp_stretch_image( Handle self, Handle image, int x, int y, int xFrom, int yF
 		return false;
 	}
 
-	if ( is_apt(aptDeviceBitmap) && ((PDeviceBitmap)self)->type == dbtBitmap ||
-		is_apt(aptImage)        && ((PImage)self)-> type == imBW )
+	if (( is_apt(aptDeviceBitmap) && ((PDeviceBitmap)self)->type == dbtBitmap) ||
+		( is_apt(aptImage)        && ((PImage)self)-> type == imBW ))
 		dst = img_put_on_bitmap;
 	else if ( is_apt(aptLayered))
 		dst = img_put_on_layered;
-	else if ( is_apt(aptDeviceBitmap) && ((PDeviceBitmap)self)->type == dbtPixmap ||
-		is_apt(aptImage)        && ((PImage)self)-> type != imBW )
+	else if (( is_apt(aptDeviceBitmap) && ((PDeviceBitmap)self)->type == dbtPixmap) ||
+		(is_apt(aptImage)        && ((PImage)self)-> type != imBW ))
 		dst = img_put_on_pixmap;
 	else if ( apc_widget_get_layered_request(self) && apc_widget_surface_is_layered(self))
 		dst = img_put_on_layered;
@@ -1586,7 +1586,7 @@ image_make_icon_handle( Handle img, Point size, Point * hotSpot)
 	else 
 		mask = i-> self-> convert_mask((Handle)i, imbpp1);
 	if ( !( ii. hbmMask  = CreateDIBitmap( dc, &bi. bmiHeader, CBM_INIT,
-		i-> mask, ( BITMAPINFO*) &bi, DIB_RGB_COLORS))) apiErr;
+		mask, ( BITMAPINFO*) &bi, DIB_RGB_COLORS))) apiErr;
 
 	if ( !notAnIcon && i-> maskType == imbpp8)
 		free(mask);
@@ -2092,7 +2092,7 @@ apc_prn_set_option( Handle self, char * option, char * value)
 	/* DM_FORMNAME string is special because it's a literal string */
 	if ( v == DM_FORMNAME) {
 		strncpy( dev-> dmFormName, value, CCHFORMNAME);
-		dev-> dmFormName[CCHFORMNAME] = 0;
+		dev-> dmFormName[CCHFORMNAME-1] = 0;
 		return true;
 	}
 
