@@ -18,8 +18,6 @@ extern "C" {
 #define HANDLE sys handle
 #define DHANDLE(x) dsys(x) handle
 
-// #define FONT_CHECK
-
 WinGuts guts;
 DWORD   rc;
 PHash   stylusMan    = nil; // pen & brush manager
@@ -48,6 +46,7 @@ WCHAR lastDeadKey = 0;
 Bool debug = false;
 
 
+
 BOOL APIENTRY
 DllMain( HINSTANCE hInstance, DWORD reason, LPVOID reserved)
 {
@@ -59,6 +58,45 @@ DllMain( HINSTANCE hInstance, DWORD reason, LPVOID reserved)
 	return TRUE;
 }
 
+typedef enum _PROCESS_DPI_AWARENESS { 
+	PROCESS_DPI_UNAWARE            = 0,
+	PROCESS_SYSTEM_DPI_AWARE       = 1,
+	PROCESS_PER_MONITOR_DPI_AWARE  = 2
+} PROCESS_DPI_AWARENESS;
+
+typedef enum _MONITOR_DPI_TYPE {
+	MDT_EFFECTIVE_DPI              = 0,
+	MDT_ANGULAR_DPI                = 1,
+	MDT_RAW_DPI                    = 2
+} MONITOR_DPI_TYPE;
+
+#ifndef MONITOR_DEFAULTTONEAREST
+#define MONITOR_DEFAULTTONULL            0
+#define MONITOR_DEFAULTTOPRIMARY         1
+#define MONITOR_DEFAULTTONEAREST         2
+#endif
+
+static HRESULT (*SetProcessDpiAwareness)(PROCESS_DPI_AWARENESS)  = NULL;
+static HRESULT (*GetDpiForMonitor)(HMONITOR,MONITOR_DPI_TYPE,UINT*,UINT*) = NULL;
+
+void
+dpi_change(void)
+{
+	UINT dx, dy;
+	POINT pt = {1,1};
+	HMONITOR m = MonitorFromPoint(pt, MONITOR_DEFAULTTONEAREST);
+	if ( GetDpiForMonitor && (GetDpiForMonitor( m, MDT_EFFECTIVE_DPI, &dx, &dy) == S_OK )) {
+		guts. displayResolution. x = dx;
+		guts. displayResolution. y = dy;
+	}
+}
+
+static void
+load_function(HMODULE module, void ** ptr, const char * name)
+{
+	(*ptr) = (void*) GetProcAddress(module, name);
+}
+
 Bool
 window_subsystem_init( char * error_buf)
 {
@@ -149,6 +187,24 @@ window_subsystem_init( char * error_buf)
 	if (!( dc = dc_alloc())) return false; 
 	guts. displayResolution. x = GetDeviceCaps( dc, LOGPIXELSX);
 	guts. displayResolution. y = GetDeviceCaps( dc, LOGPIXELSY);
+
+	/* Win8 - high dpi awareness stuff */
+	if (( os.dwMajorVersion > 5) || (os.dwMajorVersion == 5 && os.dwMinorVersion > 1)) {
+		HMODULE shcore = LoadLibrary("SHCORE.DLL");
+		if ( shcore ) {
+#define LOAD_FUNC(f) load_function(shcore, (void**) &f, #f)
+			LOAD_FUNC(SetProcessDpiAwareness);
+			LOAD_FUNC(GetDpiForMonitor);
+#undef LOAD_FUNC
+		}
+		if (
+			SetProcessDpiAwareness && GetDpiForMonitor &&
+			(SetProcessDpiAwareness( PROCESS_PER_MONITOR_DPI_AWARE) == S_OK )
+		)
+			dpi_change();
+	
+	}
+
 	{
 		LOGFONT lf;
 		HFONT   sfont;
@@ -176,21 +232,7 @@ window_subsystem_init( char * error_buf)
 		DeleteObject( SelectObject( dc, sfont));
 
 		// getting system font presets
-		memset( &guts. windowFont, 0, sizeof( Font));
-		strcpy( guts. windowFont. name, DEFAULT_WIDGET_FONT);
-		guts. windowFont. size  = DEFAULT_WIDGET_FONT_SIZE;
-		guts. windowFont. width = guts. windowFont. height = C_NUMERIC_UNDEF;
-#ifdef FONT_CHECK
-		guts. windowFont. size = 12;
-#endif
-		apc_font_pick( nilHandle, &guts. windowFont, &guts. windowFont);
-
-		guts. ncmData. cbSize = sizeof( NONCLIENTMETRICS);
-		SystemParametersInfo( SPI_GETNONCLIENTMETRICS, sizeof( NONCLIENTMETRICS),
-			( PVOID) &guts. ncmData, 0);
-		font_logfont2font( &guts. ncmData. lfMenuFont, &guts. menuFont, &guts. displayResolution);
-		font_logfont2font( &guts. ncmData. lfMessageFont, &guts. msgFont, &guts. displayResolution);
-		font_logfont2font( &guts. ncmData. lfCaptionFont, &guts. capFont, &guts. displayResolution);
+		reset_system_fonts();
 	}
 
 	memset( &guts. displayBMInfo, 0, sizeof( guts. displayBMInfo));
@@ -453,7 +495,6 @@ LRESULT CALLBACK generic_view_handler( HWND win, UINT  msg, WPARAM mp1, LPARAM m
 	UINT    orgMsg = msg;
 	Event   ev;
 	Bool    hiStage   = false;
-	int     orgCmd;
 	Bool    message_result = true;
 
 	if ( !self || appDead)
@@ -869,7 +910,7 @@ AGAIN:
 			return 0;
 		if ( is_apt( aptLayered )) {
 			PAINTSTRUCT ps;
-			HDC hdc = BeginPaint(win, &ps);
+			BeginPaint(win, &ps);
 			EndPaint(win, &ps);
 			return 0;
 		}
@@ -978,7 +1019,6 @@ AGAIN:
 	if ( hiStage)
 		ret = DefWindowProcW( win, msg, mp1, mp2);
 
-	orgCmd = ev. cmd;
 	if ( ev. cmd) 
 		message_result = v-> self-> message( self, &ev); 
 	else 
@@ -1038,7 +1078,6 @@ LRESULT CALLBACK generic_frame_handler( HWND win, UINT  msg, WPARAM mp1, LPARAM
 	UINT    orgMsg = msg;
 	Event   ev;
 	Bool    hiStage   = false;
-	int     orgCmd;
 
 	if ( !self)
 		return DefWindowProcW( win, msg, mp1, mp2);
@@ -1067,7 +1106,6 @@ LRESULT CALLBACK generic_frame_handler( HWND win, UINT  msg, WPARAM mp1, LPARAM
 		ev. cmd = cmClose;
 		break;
 	case WM_COMMAND:
-	// case WM_MENUSELECT:
 	case WM_INITMENUPOPUP:
 	case WM_INITMENU:
 	case WM_MENUCHAR:
@@ -1278,7 +1316,6 @@ LRESULT CALLBACK generic_frame_handler( HWND win, UINT  msg, WPARAM mp1, LPARAM
 	if ( hiStage)
 		ret = DefWindowProcW( win, msg, mp1, mp2);
 
-	orgCmd = ev. cmd;
 	if ( ev. cmd) v-> self-> message( self, &ev); else ev. cmd = orgMsg;
 
 	if ( var stage == csDead) orgMsg = 0;
@@ -1287,11 +1324,11 @@ LRESULT CALLBACK generic_frame_handler( HWND win, UINT  msg, WPARAM mp1, LPARAM
 	case WM_CLOSE:
 		if ( ev. cmd) {
 			if ( sys className == WC_FRAME && PWindow(self)->modal) {
-			CWindow( self)-> cancel( self);
-			return 0;
+				CWindow( self)-> cancel( self);
+				return 0;
 			} else {
-			SetWindowLongPtr( win, GWLP_USERDATA, 0);
-			Object_destroy(( Handle) v);
+				SetWindowLongPtr( win, GWLP_USERDATA, 0);
+				Object_destroy(( Handle) v);
 			}
 			break;
 		} else
@@ -1355,7 +1392,8 @@ LRESULT CALLBACK layered_frame_handler( HWND win, UINT  msg, WPARAM mp1, LPARAM
 		update_layered_frame(self);
 		return DefWindowProcW( win, msg, mp1, mp2);
 
-	case WM_WINDOWPOSCHANGED: {
+	case WM_WINDOWPOSCHANGED: 
+		{
 			LPWINDOWPOS l = ( LPWINDOWPOS) mp2;
 			Bool updated = false;
 
@@ -1437,6 +1475,16 @@ LRESULT CALLBACK generic_app_handler( HWND win, UINT  msg, WPARAM mp1, LPARAM mp
 		case WM_FONTCHANGE:
 			destroy_font_hash();
 			break;
+		case WM_DPICHANGED:
+			{
+				Event ev = {cmFontChanged};
+				dpi_change();
+				reset_system_fonts();
+				destroy_font_hash();
+				font_clean();
+				PComponent(application)-> self-> message( application, &ev);
+			}
+			break;
 		case WM_COMPACTING:
 			stylus_clean();
 			font_clean();
